@@ -1,27 +1,27 @@
 #![allow(improper_ctypes)]
 
-use fluence::fce;
+use fluence::marine;
 
 pub fn main() {}
 
-#[fce]
+#[marine]
 #[link(wasm_import_module = "arrays_passing_effector")]
 extern "C" {
-    #[fce]
+    #[marine]
     pub fn func_1() -> &String;
 
-    #[fce]
+    #[marine]
     pub fn func_2() -> &Vec<Vec<Vec<Vec<u8>>>>;
 
-    #[fce]
+    #[marine]
     pub fn func_3() -> Vec<&Vec<Vec<Vec<u8>>>>;
 
-    #[fce]
+    #[marine]
     pub fn func_4() -> Vec<Vec<&Vec<Vec<u8>>>>;
 
-    #[fce]
+    #[marine]
     pub fn func_5() -> Vec<Vec<Vec<&Vec<u8>>>>;
 
-    #[fce]
+    #[marine]
     pub fn func_6() -> Vec<Vec<Vec<Vec<&u8>>>>;
 }
